@@ -17,10 +17,10 @@ import dropbox
 import hashlib
 import webbrowser
 import yaml
+import time
 # mine
 from hwrt.HandwrittenData import HandwrittenData
-import time
-import utils
+import hwrt.utils as utils
 
 
 def input_string(question=""):
